import {
  QueueItemModel,
  QueueModel,
} from 'src/modules/queue/data/models/queue.model';
import { CustomerQueueManager } from './customer-queue.manager';
import { QueueCondition } from '../formula/queue-condition.formula';

export class CustomerQueueItemListManager extends CustomerQueueManager {
  private queues: QueueModel[] = [];
  currentQueues(queues: QueueModel[]) {
    this.queues = queues;
  }
  get data() {
    const tickets = this.tickets;
    const queueCondition = new QueueCondition(this.queues);

    const ticketItems = {};
    tickets.forEach((ticket) => {
      ticket.items.forEach((item) => {
        const item_id = item.item.item_queue?.id ?? item.item.id;
        const currentItem = ticketItems[item_id];
        ticketItems[item_id] = currentItem ? [...currentItem, item] : [item];
      });
    });

    return Object.values<QueueItemModel[]>(ticketItems).map((items) => {
      const item = items[0];
      const item_qty = items.reduce((acc, item) => acc + item.qty, 0);
      const queueItem = item.item.item_queue ?? item.item;
      return {
        id: queueItem.id,
        queue_item_id: item.id,
        title: queueItem.name,
        image_url: item.item.image_url,
        qty: item_qty,

        queue_condition: queueCondition.condition(queueItem.id),
        ...queueCondition.condition(queueItem.id),
      };
    });
  }
}
